/*
 *	copy_file
 *
 *	Author: David L. Markowitz (dav@gtc.com)
 */

#include "tapecv.h"
#include <sys/types.h>
#include <sys/ioctl.h>
#include <sys/mtio.h>

copy_file(from, to)
struct td from, to;
{
	int records_copied;
	struct mtop mtop;
	int real_block;

	records_copied = 0;
	if (boot_tape  &&  files_copied != 0) {
		/* Assume a boot tape's special format (Argh!) */
		real_block = max_block;
		max_block = 512;
		if (copy_record(from, to)) {
			max_block = real_block;
			goto eof;
		}
		max_block = real_block;
		records_copied++;
	}

	for (; ; records_copied++)
		if (copy_record(from, to))
			break;

eof:
	/* Write an EOF mark on the tape */
	if (to.local) {
		mtop.mt_op = MTWEOF;
		mtop.mt_count = 1;
		ioctl(to.fd, MTIOCTOP, &mtop);
	}
	else {
		sprintf(cmd, "I%d\n1\n", MTWEOF);
		if (write(to.fd, cmd, strlen(cmd)) < 0)
			perror("copy_file - write(to) failed");
		read(to.fd, response, 1);
		if (response[0] != 'A') {
			fdgets(to.fd, response);	/* Error number */
			fdgets(to.fd, response);	/* Error msg */
			fprintf(stderr, "copy_file: ioctl failed: %s",
						response);
			exit(-1);
		}
		fdgets(to.fd, response);	/* discard this junk */
	}

	if (verbose) {
		if (records_copied > 0)
			printf("Copied file %d: %d records\n",
				files_copied+1, records_copied);
		else
			printf("End of tape - rewinding\n");
	}

	if (records_copied > 0)
		return(0);	/* Not EOT */
	else
		return(1);	/* Empty file ::= EOT */
}
