/*
 *	initialize
 *
 *	Author: David L. Markowitz (dav@gtc.com)
 */

#include "tapecv.h"
#include <netdb.h>

initialize(argc, argv)
int argc;
char **argv;
{
	char	*cp, *index();
	char	from_host[32], to_host[32];
	char	*from_host_name = from_host, *to_host_name = to_host;
	struct servent *execserv, *getservbyname();

	/* Defaults */
	nfiles = -1;			/* No limit */
	verbose = 0;
	max_block = MAXBLK;

	while (argc > 3) {
		if (strcmp(argv[1], "-v") == 0) {
			verbose++;
		}
		else if (strcmp(argv[1], "-b") == 0) {
			max_block = atol(argv[2]) * 512;
			if (max_block > MAXBLK) {
				printf("Block size %d too large!\n", max_block);
				exit(-1);
			}
			else if (max_block < 512) {
				printf("Block size %d too small!\n", max_block);
				exit(-1);
			}
			else
			   printf("Block size set to %d bytes (%d blocks)\n",
						max_block, max_block/512);
			/* Extra decrement */
			argc--;
			argv++;
		}
		else if (strcmp(argv[1], "-B") == 0) {
			boot_tape++;
			max_block = 8192;
			printf("Block size set to 8192 bytes (16 blocks)\n");
		}
		else if (strcmp(argv[1], "-n") == 0) {
			argc--;
			argv++;
			nfiles = atoi(argv[1]);
			printf("Copying only the first %d files\n", nfiles);
		}

		argc--;
		argv++;
	}

	/* get drive names */
	if (argc != 3)
		format();

	if ((cp=index(argv[1], ':')) == NULL) {
		strcpy(from_dev, argv[1]);
		gethostname(from_host, 31);
		from.local = 1;
	}
	else {
		*cp = NULL;
		strcpy(from_host, argv[1]);
		strcpy(from_dev, cp+1);
		from.local = 0;
	}
	if (strncmp(from_dev, "/dev/rmt", 8) == 0)
		from.cartridge = 0;
	else
		from.cartridge = 1;

	if ((cp=index(argv[2], ':')) == NULL) {
		strcpy(to_dev, argv[2]);
		gethostname(to_host, 31);
		to.local = 1;
	}
	else {
		*cp = NULL;
		strcpy(to_host, argv[2]);
		strcpy(to_dev, cp+1);
		to.local = 0;
	}
	if (strncmp(to_dev, "/dev/rmt", 8) == 0)
		to.cartridge = 0;
	else
		to.cartridge = 1;

	if (verbose)
		printf("Copying from %s:%s to %s:%s\n",
			from_host, from_dev, to_host, to_dev);

	if ((execserv = getservbyname("exec", "tcp")) == NULL)
		perror("getservbyname(exec, tcp) failed");

	/* Initiate rmt's on remote hosts */
	if (from.local) {
		if ((from.fd = open(from_dev, 0)) == -1) {
			perror("open(from_dev) failed");
			exit(-1);
		}
	}
	else {
		if ((from.fd = rexec(&from_host_name, execserv->s_port, 
					NULL, NULL, "/etc/rmt", NULL)) == -1) {
			perror("rexec(from, rmt) failed");
			exit(-1);
		}
	}

	if (!to.local) {
		if ((to.fd = rexec(&to_host_name, execserv->s_port,
					NULL, NULL, "/etc/rmt", NULL)) == -1) {
			perror("rexec(to, rmt) failed");
			exit(-1);
		}
	}
	else {
		if ((to.fd = open(to_dev, 2)) == -1) {
			perror("open(to_dev) failed");
			exit(-1);
		}
	}

	return;
}
